@@ -4,18 +4,14 @@ use 5.010;
 use strict;
 use warnings;
 
+our $VERSION = '0.08';
+
 =head1 NAME
 
 C<Device::FTDI> - use USB-attached serial interface chips from I<FTDI>.
 
-=head1 VERSION
-
-Version 0.06
-
 =cut
 
-our $VERSION = '0.07';
-
 use Carp;
 
 our @ISA = qw(Exporter);
@@ -317,7 +313,7 @@ sub set_flow_control {
 
     $dev->set_line_property($bits, $stop_bit, $parity, $break)
 
-Sets line characteristics. Last parameters may be ommited. Following values are
+Sets line characteristics. Last parameters may be omitted. Following values are
 acceptable for parameters (* marks default value):
 
 =over 4
@@ -505,6 +501,9 @@ value configures a line as output. I<$mode> may be one of the following:
 
 (export tag C<:bitmode>)
 
+To use the C<BITMODE_MPSSE> mode, you may prefer to use the
+L<Device::FTDI::MPSSE> subclass instead.
+
 =cut
 
 sub set_bitmode {
